@@ -9,10 +9,13 @@ from pathlib import Path
 import fancybox as fb  # needed
 from termcolor import colored, cprint
 
+from .git import Git
+
 
 class Local:
     def __init__(self):
         self.path = ""
+        self.git = Git(self)
 
     def setPath(self, path):
         self.path = path
