@@ -11,6 +11,8 @@ from pathlib import Path
 import fancybox as fb  # needed
 from termcolor import colored, cprint
 
+from .git import Git
+
 
 class Remote:
     def __init__(self, ip, user, password, port=22):
@@ -19,6 +21,7 @@ class Remote:
         self.user = user
         self.password = password
         self.path = ""
+        self.git = Git(self)
 
     def connect(self):
         self.con = Connection(self.ip, port=self.port, user=self.user, connect_kwargs={
@@ -26,6 +29,9 @@ class Remote:
         if(self.con):
             print(colored("Remote VPS Conntectd",
                           'yellow', attrs=['reverse', 'bold']))
+        else:
+            print(colored("Couldn't connect to VPS",
+                          'red', attrs=['reverse', 'bold']))
 
     def setPath(self, path):
         Path(os.path.dirname(path)).mkdir(parents=True, exist_ok=True)
@@ -46,4 +52,4 @@ class Remote:
         print(colored(self.path+"$", 'cyan', attrs=['reverse', 'bold']) +
               colored(" " + cmd, 'green', attrs=['reverse', 'bold']))
         with self.con.cd(self.path):
-            self._exe(cmd)
+            return self._exe(cmd)
